@@ -7,12 +7,13 @@ freezegun
 
 """
 from .api import freeze_time
+from .config import configure
 
 __title__ = 'freezegun'
-__version__ = '0.3.11'
+__version__ = '1.1.0'
 __author__ = 'Steve Pulec'
 __license__ = 'Apache License 2.0'
 __copyright__ = 'Copyright 2012 Steve Pulec'
 
 
-__all__ = ["freeze_time"]
+__all__ = ["freeze_time", "configure"]
