@@ -15,13 +15,13 @@ from freezegun.api import FakeDatetime, FakeDate
 
 try:
     import maya
-
 except ImportError:
     maya = None
 
 # time.clock was removed in Python 3.8
 HAS_CLOCK = hasattr(time, 'clock')
 HAS_TIME_NS = hasattr(time, 'time_ns')
+HAS_MONOTONIC_NS = hasattr(time, 'monotonic_ns')
 
 class temp_locale(object):
     """Temporarily change the locale."""
@@ -58,12 +58,14 @@ def test_simple_api():
 
     freezer.start()
     assert time.time() == expected_timestamp
+    assert time.monotonic() >= 0.0
     assert datetime.datetime.now() == datetime.datetime(2012, 1, 14)
     assert datetime.datetime.utcnow() == datetime.datetime(2012, 1, 14)
     assert datetime.date.today() == datetime.date(2012, 1, 14)
     assert datetime.datetime.now().today() == datetime.datetime(2012, 1, 14)
     freezer.stop()
     assert time.time() != expected_timestamp
+    assert time.monotonic() >= 0.0
     assert datetime.datetime.now() != datetime.datetime(2012, 1, 14)
     assert datetime.datetime.utcnow() != datetime.datetime(2012, 1, 14)
     freezer = freeze_time("2012-01-10 13:52:01")
@@ -114,6 +116,7 @@ def test_zero_tz_offset_with_time():
     assert datetime.datetime.now() == datetime.datetime(1970, 1, 1)
     assert datetime.datetime.utcnow() == datetime.datetime(1970, 1, 1)
     assert time.time() == 0.0
+    assert time.monotonic() >= 0.0
     freezer.stop()
 
 
@@ -126,6 +129,7 @@ def test_tz_offset_with_time():
     assert datetime.datetime.now() == datetime.datetime(1969, 12, 31, 20)
     assert datetime.datetime.utcnow() == datetime.datetime(1970, 1, 1)
     assert time.time() == 0.0
+    assert time.monotonic() >= 0
     freezer.stop()
 
 
@@ -198,6 +202,29 @@ def test_bad_time_argument():
         assert False, "Bad values should raise a ValueError"
 
 
+def test_time_monotonic():
+    initial_datetime = datetime.datetime(year=1, month=7, day=12,
+                                        hour=15, minute=6, second=3)
+    with freeze_time(initial_datetime) as frozen_datetime:
+        monotonic_t0 = time.monotonic()
+        if HAS_MONOTONIC_NS:
+            monotonic_ns_t0 = time.monotonic_ns()
+
+        frozen_datetime.tick()
+        monotonic_t1 = time.monotonic()
+        assert monotonic_t1 == monotonic_t0 + 1.0
+        if HAS_MONOTONIC_NS:
+            monotonic_ns_t1 = time.monotonic_ns()
+            assert monotonic_ns_t1 == monotonic_ns_t0 + 1000000000
+
+        frozen_datetime.tick(10)
+        monotonic_t11 = time.monotonic()
+        assert monotonic_t11 == monotonic_t1 + 10.0
+        if HAS_MONOTONIC_NS:
+            monotonic_ns_t11 = time.monotonic_ns()
+            assert monotonic_ns_t11 == monotonic_ns_t1 + 10000000000
+
+
 def test_time_gmtime():
     with freeze_time('2012-01-14 03:21:34'):
         time_struct = time.gmtime()
@@ -261,9 +288,10 @@ def test_strftime():
 
 
 def test_real_strftime_fall_through():
-    with freeze_time(ignore=['_pytest']):
-        time.strftime('%Y')
-        time.strftime('%Y', (2001, 1, 1, 1, 1, 1, 1, 1, 1)) == '2001'
+    this_real_year = datetime.datetime.now().year
+    with freeze_time():
+        assert time.strftime('%Y') == str(this_real_year)
+        assert time.strftime('%Y', (2001, 1, 1, 1, 1, 1, 1, 1, 1)) == '2001'
 
 
 def test_date_object():
@@ -484,6 +512,22 @@ def test_isinstance_without_active():
     assert isinstance(today, datetime.date)
 
 
+class TestUnitTestMethodDecorator(unittest.TestCase):
+    @freeze_time('2013-04-09')
+    def test_method_decorator_works_on_unittest(self):
+        self.assertEqual(datetime.date(2013, 4, 9), datetime.date.today())
+
+    @freeze_time('2013-04-09', as_kwarg='frozen_time')
+    def test_method_decorator_works_on_unittest_kwarg_frozen_time(self, frozen_time):
+        self.assertEqual(datetime.date(2013, 4, 9), datetime.date.today())
+        self.assertEqual(datetime.date(2013, 4, 9), frozen_time.time_to_freeze.today())
+
+    @freeze_time('2013-04-09', as_kwarg='hello')
+    def test_method_decorator_works_on_unittest_kwarg_hello(self, **kwargs):
+        self.assertEqual(datetime.date(2013, 4, 9), datetime.date.today())
+        self.assertEqual(datetime.date(2013, 4, 9), kwargs.get('hello').time_to_freeze.today())
+
+
 @freeze_time('2013-04-09')
 class TestUnitTestClassDecorator(unittest.TestCase):
 
@@ -633,6 +677,20 @@ def test_time_with_nested():
         assert time() == second
 
 
+def test_monotonic_with_nested():
+    from time import monotonic
+
+    with freeze_time('2015-01-01') as frozen_datetime_1:
+        initial_monotonic_1 = time.monotonic()
+        with freeze_time('2015-12-25') as frozen_datetime_2:
+            initial_monotonic_2 = time.monotonic()
+            frozen_datetime_2.tick()
+            assert time.monotonic() == initial_monotonic_2 + 1
+        assert time.monotonic() == initial_monotonic_1
+        frozen_datetime_1.tick()
+        assert time.monotonic() == initial_monotonic_1 + 1
+
+
 def test_should_use_real_time():
     frozen = datetime.datetime(2015, 3, 5)
     expected_frozen = 1425513600.0
